require "lunit"
require "lfs"
module("extra_functions_tests", package.seeall, lunit.testcase)

-- Suite of functions that can be used for other lua implementations besides Synergy

function setup()
	local currentdir = lfs.currentdir()
	package.path = package.path..";"..currentdir.."/share/?.lua;"
	require "extra"
end

function test_string_trim()
	local s = " String with whitespaces "
	s = string.trim(s)
	assert_equal("String with whitespaces", s, "String was not trimmed, got "..s)
end

function test_serialize()
	local t = {}
	t.one = 1
	t.two = 2
	t.three = 3
	s = serialize(t)
	assert_string(s, "Expected a serialized string got "..type(s)..s)
end

function test_deserialize()
	local s = '{["one"]=1,["three"]=3,["two"]=2,}'
	local t = deserialize(s)
	assert_table(t, "Expected a deserialized table got ".. type(t))
end

function test_url_encode()
	local s = "String [1] - / \\ #ü å ä ö ñ"
	url_encoded_string = url_encode(s)
	assert_equal("String+%5B1%5D+-+%2F+%5C+%23%C3%BC+%C3%A5+%C3%A4+%C3%B6+%C3%B1", url_encoded_string, "String is not encoded as expected")
end

function test_url_decode()
	local url_encoded_string = "String+%5B1%5D+-+%2F+%5C+%23%C3%BC+%C3%A5+%C3%A4+%C3%B6+%C3%B1"
	local s = url_decode(url_encoded_string)
	assert_equal("String [1] - / \\ #ü å ä ö ñ", s, "String was not decoded as expected")

end
